==> am_mod_evt_0_2.zip: am_mod_evt_0_2/components/evt/language/1/barnraiser_01/item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------




// HEADERS
$lang['hdr_item'] =								"item";
$lang['hdr_comments'] =							"comments";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_feedback'] =							"feedback";
$lang['hdr_feedback_summery'] =					"feedback summary";
$lang['hdr_attendee'] =							"attendee";
$lang['hdr_people'] =							"people";
$lang['hdr_people_attending'] =					"people on this activity";
$lang['hdr_my_participation'] =					"my participation";


// BODY TEXT
$lang['txt_last_edited'] =						"last edited";
$lang['txt_published_to'] = 					"published to";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_no_comment_allowed_login'] = 		"Please <a href='access.php'>login</a> or <a href='register.php'>register</a> to leave your comments.";
$lang['txt_no_participation'] = 				"You are not going to this activity";
$lang['txt_pending'] =							"pending";
$lang['txt_barred'] =							"barred";
$lang['txt_active'] =							"active";
$lang['txt_activity'] =							"activity";
$lang['txt_mark_track'] =						"mark and track";
$lang['txt_start'] =							"start";
$lang['txt_duration'] =							"duration";
$lang['txt_hours'] =							"hours";
$lang['txt_days'] =								"days";
$lang['txt_location'] =							"location";
$lang['txt_venue'] =							"venue";
$lang['txt_participants'] =						"participants";
$lang['txt_participants_no_limit'] =			"this event has no limit for participants";
$lang['txt_did_you_go'] =						"Did you go to this activity?";
$lang['txt_did_you_enjoy'] =					"Did you enjoy it?";
$lang['txt_did_not_go'] =						"Why did you not go to this event?";
$lang['txt_arrange_again'] =					"Would you like the organisers to arrange another event like it?";
$lang['txt_leave_comment'] =					"Would you like to leave a comment for the organisers?";
$lang['txt_feedback_to_maintainer'] =			"Do you want this feedback only to be for the maintainer?s";
$lang['txt_yes'] =								"yes";
$lang['txt_no'] =								"no";
$lang['txt_of'] =								"of";
$lang['txt_comment'] =							"Comment:";
$lang['txt_did_not_come'] =						"I didn't come because:";
$lang['txt_did_you_know'] =						"did you know that...";
$lang['txt_users_participated'] = 				"users participated in this event";
$lang['txt_users_enjoyed'] =					"of them enjoyed this event";
$lang['txt_user_participate_again'] = 			"would like to participate in a similar event";
$lang['txt_do_you_want_to_write'] =				"Do you want to write";
$lang['txt_to_event'] =							"to this event?";
$lang['txt_started_by'] =						"started by";
$lang['txt_going_with'] =						"I am going with";
$lang['txt_people_attending'] =					"people are attending this activity";
$lang['txt_joined'] =							"joined";
$lang['txt_status'] =							"status";
$lang['txt_bookmark'] =							"bookmark this event";
$lang['txt_remove_bookmark'] =					"remove bookmark from this event";
$lang['txt_alt_remove_recommendation'] =		"remove this recommendation";
$lang['txt_title_remove_recommendation'] =		"remove this recommendation";
$lang['txt_title_add_recommendation'] =			"recommend this event to other users";
$lang['txt_alt_add_recommendation'] =			"recommend this event to other users";
$lang['txt_places'] =							"places";

// LINKS
$lang['hrf_participate'] =						"participate";
$lang['hrf_withdraw'] =							"withdraw";
$lang['hrf_manage'] = 							"manage";
$lang['hrf_go_with'] =							"I want to go with";
$lang['hrf_dont_go_with'] =						"I dont want to go with";
$lang['hrf_join'] =								"join";

?>

==> am_mod_evt_0_5.zip: am_mod_evt_0_5/components/evt/language/1/barnraiser_01/item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------




// HEADERS
$lang['hdr_item'] =								"item";
$lang['hdr_comments'] =							"comments";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_feedback'] =							"feedback";
$lang['hdr_feedback_summery'] =					"feedback summary";
$lang['hdr_attendee'] =							"attendee";
$lang['hdr_people'] =							"people";
$lang['hdr_people_attending'] =					"people on this activity";
$lang['hdr_my_participation'] =					"my participation";
$lang['hdr_tags'] =								"tags";

// BODY TEXT
$lang['txt_last_edited'] =						"last edited";
$lang['txt_published_to'] = 					"published to";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_no_comment_allowed_login'] = 		"Please <a href='access.php'>login</a> or <a href='register.php'>register</a> to leave your comments.";
$lang['txt_no_participation'] = 				"You are not going to this activity";
$lang['txt_pending'] =							"pending";
$lang['txt_barred'] =							"barred";
$lang['txt_active'] =							"active";
$lang['txt_activity'] =							"activity";
$lang['txt_mark_track'] =						"mark and track";
$lang['txt_start'] =							"start";
$lang['txt_duration'] =							"duration";
$lang['txt_hours'] =							"hours";
$lang['txt_days'] =								"days";
$lang['txt_location'] =							"location";
$lang['txt_venue'] =							"venue";
$lang['txt_participants'] =						"participants";
$lang['txt_participants_no_limit'] =			"this event has no limit for participants";
$lang['txt_did_you_go'] =						"Did you go to this activity?";
$lang['txt_did_you_enjoy'] =					"Did you enjoy it?";
$lang['txt_did_not_go'] =						"Why did you not go to this event?";
$lang['txt_arrange_again'] =					"Would you like the organisers to arrange another event like it?";
$lang['txt_leave_comment'] =					"Would you like to leave a comment for the organisers?";
$lang['txt_feedback_to_maintainer'] =			"Do you want this feedback only to be for the maintainers?";
$lang['txt_yes'] =								"yes";
$lang['txt_no'] =								"no";
$lang['txt_of'] =								"of";
$lang['txt_comment'] =							"Comment:";
$lang['txt_did_not_come'] =						"I didn't come because:";
$lang['txt_did_you_know'] =						"did you know that...";
$lang['txt_users_participated'] = 				"users participated in this event";
$lang['txt_users_enjoyed'] =					"of them enjoyed this event";
$lang['txt_user_participate_again'] = 			"would like to participate in a similar event";
$lang['txt_do_you_want_to_write'] =				"Do you want to write";
$lang['txt_to_event'] =							"to this event?";
$lang['txt_started_by'] =						"started by";
$lang['txt_going_with'] =						"I am going with";
$lang['txt_people_attending'] =					"people are attending this activity";
$lang['txt_joined'] =							"joined";
$lang['txt_status'] =							"status";
$lang['txt_bookmark'] =							"bookmark this event";
$lang['txt_remove_bookmark'] =					"remove bookmark from this event";
$lang['txt_alt_remove_recommendation'] =		"remove this recommendation";
$lang['txt_title_remove_recommendation'] =		"remove this recommendation";
$lang['txt_title_add_recommendation'] =			"recommend this event to other users";
$lang['txt_alt_add_recommendation'] =			"recommend this event to other users";
$lang['txt_places'] =							"places";

// LINKS
$lang['hrf_participate'] =						"participate";
$lang['hrf_withdraw'] =							"withdraw";
$lang['hrf_manage'] = 							"manage";
$lang['hrf_go_with'] =							"I want to go with";
$lang['hrf_dont_go_with'] =						"I dont want to go with";
$lang['hrf_join'] =								"join";
$lang['href_respect'] =							"respect";


//SUBMITS
$lang['sub_tag_ok'] =							"OK";
$lang['sub_tag_delete'] =						"DEL";

?>
